/* 
  AgentManager.h

  Barry McMullin <mcmullin@eeng.dcu.ie>
  07-OCT-1996

*/

#import <objectbase/SwarmObject.h>
#import <simtools.h>

@interface AgentManager : SwarmObject {
  id agentClass;

  id agentList;
  id addedAgentQueue;
  id droppedAgentQueue;
}


-setAgentClass: (id) classId;
-createEnd;


-(id) getAgentList;
-(int) getCount;

-(id) randomAgent;

-(id) createAgent;
-dropAgent: (id) agent;

-processQueues;

-saveTo: (OutFile *) file;
-loadFrom: (InFile *) file;

-(void) drop; // Overridden;


@end
